@@ -776,8 +776,8 @@ static void cmdline_view_utf8_2line()
                     memcpy(line1, cstr, pointer-cstr);
                     line1[pointer-cstr] = 0;
 
-                    mmvprintw(maxy-2, 2, line1);
-                    mmvprintw(maxy-1, 0, pointer);
+                    mmvprintw(maxy-2, 2, "%s", line1);
+                    mmvprintw(maxy-1, 0, "%s", pointer);
                     break;
                 }
             }
@@ -785,7 +785,7 @@ static void cmdline_view_utf8_2line()
     }
     else {
         BOOL cmd = TRUE;
-        mmvprintw(maxy-2, 2, cstr);
+        mmvprintw(maxy-2, 2, "%s", cstr);
     }
 
     int utfpos = str_pointer2kanjipos(kUtf8, cstr, cstr + gCmdLineCursor);
